@@ -15,15 +15,13 @@
  */
 
 #include "examplewindow.h"
-#include <gtkmm/main.h>
+#include <gtkmm/application.h>
 
 int main(int argc, char *argv[])
 {
-  Gtk::Main kit(argc, argv);
+  Glib::RefPtr<Gtk::Application> app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
 
   ExampleWindow window;
   //Shows the window and returns when it is closed.
-  Gtk::Main::run(window);
-
-  return 0;
+  return app->run(window);
 }
