@@ -34,15 +34,14 @@ ExampleWindow::ExampleWindow()
   m_container.add(m_first);
   m_container.add(m_second);
 
-  // Events
+  // Events.
+  // We override the default event signal handler.
   add_events(Gdk::KEY_PRESS_MASK);
-  signal_key_press_event().connect(sigc::mem_fun(*this,
-    &ExampleWindow::on_key_press_event));
 
   show_all_children();
 }
 
-bool ExampleWindow::on_key_press_event(GdkEventKey *event)
+bool ExampleWindow::on_key_press_event(GdkEventKey* event)
 {
   //GDK_MOD1_MASK -> the 'alt' key(mask)
   //GDK_KEY_1 -> the '1' key
@@ -53,24 +52,27 @@ bool ExampleWindow::on_key_press_event(GdkEventKey *event)
     (event->state &(GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)) == GDK_MOD1_MASK)
   {
     m_first.set_active();
+    //returning true, cancels the propagation of the event
+    return true;
   }
   else if((event->keyval == GDK_KEY_2) &&
     (event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)) == GDK_MOD1_MASK)
   {
     //and the second radio button, when we press alt + 2
     m_second.set_active();
+    return true;
   }
   else if(event->keyval == GDK_KEY_Escape)
   {
     //close the window, when the 'esc' key is pressed
     hide();
+    return true;
   }
 
-  //returning true, cancels the propagation of the event
-  return true;
+  //if the event has not been handled, call the base class
+  return Gtk::Window::on_key_press_event(event);
 }
 
-
 ExampleWindow::~ExampleWindow()
 {
 }
