@@ -25,6 +25,13 @@ ExampleWindow::ExampleWindow()
   m_Frame_NotAccelerated("Not accelerated"),
   m_Frame_Accelerated("Accelerated"),
   m_VBox_Main(Gtk::ORIENTATION_VERTICAL, 5),
+  m_VBox(Gtk::ORIENTATION_VERTICAL),
+  m_VBox_Day(Gtk::ORIENTATION_VERTICAL),
+  m_VBox_Month(Gtk::ORIENTATION_VERTICAL),
+  m_VBox_Year(Gtk::ORIENTATION_VERTICAL),
+  m_VBox_Accelerated(Gtk::ORIENTATION_VERTICAL),
+  m_VBox_Value(Gtk::ORIENTATION_VERTICAL),
+  m_VBox_Digits(Gtk::ORIENTATION_VERTICAL),
   m_Label_Day("Day: "),
   m_Label_Month("Month: "),
   m_Label_Year("Year: "),
@@ -32,7 +39,7 @@ ExampleWindow::ExampleWindow()
   m_Label_Digits("Digits: "),
   m_adjustment_day( Gtk::Adjustment::create(1.0, 1.0, 31.0, 1.0, 5.0, 0.0) ),
   m_adjustment_month( Gtk::Adjustment::create(1.0, 1.0, 12.0, 1.0, 5.0, 0.0) ),
-  m_adjustment_year( Gtk::Adjustment::create(1998.0, 0.0, 2100.0, 1.0, 100.0, 0.0) ),
+  m_adjustment_year( Gtk::Adjustment::create(2012.0, 1.0, 2200.0, 1.0, 100.0, 0.0) ),
   m_adjustment_value( Gtk::Adjustment::create(0.0, -10000.0, 10000.0, 0.5, 100.0, 0.0) ),
   m_adjustment_digits( Gtk::Adjustment::create(2.0, 1.0, 5.0, 1.0, 1.0, 0.0) ),
   m_SpinButton_Day(m_adjustment_day),
